/* Author: Tuan Truong + Kyle O'Neil 
 * Version: 2.0 (March 9, 2016) 
 * Brief: This is a program that calibrates the ESC using 
 * the teensyLC board. Using the prebuilt arduino
 * servo library, the teensy will set all servos to 
 * maximum speed/angle and hold it there for about three seconds.
 * After that all servos will be set to the lowest speed and
 * this should complete calibration setup. It will wait a
 * bit before running the ESC at full speed. For battery 
 * protection, a timer is implemented to ensure the Whitebox 
 * is not run for more than 5 minutes. 
 * Attribution: This program uses functions and libraries 
 * from the Arduino website (https://www.arduino.cc/). A link 
 * to the Creative Commons license can be found at 
 * http://creativecommons.org/licenses/by-sa/3.0/
 */


// Libraries
#include <Servo.h> 
#include "whitebox.h"

// Macros
#define LED_PIN     13 
#define PWM_PIN_1   9      //Hover Engine 1 
#define PWM_PIN_2   10     //Hover Engine 2 
#define PWM_PIN_3   16     //Hover Engine 3 
#define PWM_PIN_4   17     //Hover Engine 4
#define RUN_BTN     21     //Power button 
#define delaytime   500    //delay for loop()
#define timer       300000 //in milliseconds. 300000ms = 5min

//Have ability to show what the Teensy is doing using a LED
#define LED_ON()    digitalWrite(LED_PIN, HIGH)
#define LED_OFF()   digitalWrite(LED_PIN, LOW)

// white box object
Whitebox wb(PWM_PIN_1, PWM_PIN_2, PWM_PIN_3, PWM_PIN_4);

void setup() {
    // Set up DDR
    pinMode(LED_PIN, OUTPUT);
    pinMode(RUN_BTN, INPUT);
    LED_ON();

    //calibration is necessary to start up the ESC
    wb.calibrate();

    // wait a bit
    delay(1000);
    LED_OFF();
}

//define runtime calculator outside of loop 
int runtime; //elapsed time in milliseconds  

void loop() {
    if(readBtn()) { //If the power switch is on, 
      elapsedMillis looptime; //time spent in the loop running 
        
        wb.spinAllMtr(wb.getMaxSpeed());
        LED_ON();
          if(runtime >= timer) { 
            turnoff(); 
          }
         runtime = runtime + looptime; 
    } 
    else {
        turnoff(); 
    }
    delay(delaytime);

    //update for the delay too but only if the switch is still on 
    if(readBtn()) {
    runtime = runtime + delaytime; 
    }
}

void turnoff() {
  wb.spinAllMtr(wb.getMinSpeed());
  LED_OFF();
}

//function to know if button is on or off 
int readBtn(void){
    return(digitalRead(RUN_BTN));
}
