/* Author: Tuan Truong
 * Version: 2.0 (March 9, 2016) 
 * Brief: Source file for the Whitebox class. Functions are 
 * provided to allow the proper speeds to be written to the 
 * correct motor pins. 
 * Attribution: This program uses functions and libraries 
 * from the Arduino website (https://www.arduino.cc/). A link 
 * to the Creative Commons license can be found at 
 * http://creativecommons.org/licenses/by-sa/3.0/
 */
#include<Arduino.h>
#include"whitebox.h"
#include<Servo.h>

Whitebox::Whitebox(int mtr1_pin, int mtr2_pin, int mtr3_pin, int mtr4_pin){

  //The speed range was found using guess and check 
	maxSpeed = 180;
	minSpeed = 10;

  //Create four motors that can use the Servo functions 
  Mtr1 = new Servo();
  Mtr2 = new Servo();
  Mtr3 = new Servo();
  Mtr4 = new Servo();
   
  //Associate those motors with the appropriate pins 
  Mtr1->attach(mtr1_pin);
  Mtr2->attach(mtr2_pin);
  Mtr3->attach(mtr3_pin);
  Mtr4->attach(mtr4_pin);
}

//Calibration that is necessary for the ESC
void Whitebox::calibrate(void){
    
    //spin all motors at max speed
    //hold that for 3 seconds about
    //then spin all at the lowest speed
    spinAllMtr(maxSpeed);
    delay(1000);
    delay(1000);
    delay(1000);
    spinAllMtr(minSpeed);
    delay(1000);
}

void Whitebox::spinAllMtr(int speed){

  //add if statements in case someone tries to spin 
  //the motors outside the given range 
	if (speed > maxSpeed) speed = maxSpeed;
	else if (speed < minSpeed) speed = minSpeed;

    Mtr1->write(speed);
    Mtr2->write(speed);
    Mtr3->write(speed);
    Mtr4->write(speed);
}

void Whitebox::setMaxSpeed(int speed){
    if(speed < minSpeed){
        maxSpeed = minSpeed;
    }
    if(speed > 180 ){
        maxSpeed =180;
    }
}

void Whitebox::setMinSpeed(int speed){
    if(speed > maxSpeed){
        minSpeed = maxSpeed;
    }
    if( speed < 0 ){
        minSpeed = 0;
    }
}

//get function for MinSpeed
int Whitebox::getMinSpeed(void){
    return(minSpeed);
}

//get function for MaxSpeed
int Whitebox::getMaxSpeed(void){
    return(maxSpeed);
}
